/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2009 Jaroslav Tulach
 */

package cz.xelfi.quoridor.webidor;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.TreeSet;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlValue;

/**
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
@XmlRootElement
@XmlAccessorType(XmlAccessType.NONE)
public final class User extends Object {
    @XmlAttribute
    private String id;
    @XmlElement(name="property")
    private List<Property> properties;
    private transient Set<String> permissions;

    User() {
    }

    public User(String id) {
        this.id = id;
    }

    public void addProperty(String name, String value) {
        if (properties == null) {
            properties = new ArrayList<Property>();
        }
        properties.add(new Property(name, value));
    }

    public void addPermission(String permission) {
        if (permissions == null) {
            permissions = new TreeSet<String>();
        }
        permissions.add(permission);
    }

    public String getProperty(String name) {
        if (properties == null) {
            return null;
        }
        for (Property p : properties) {
            if (p.name.equals(name)) {
                return p.value;
            }
        }
        return null;
    }

    public boolean hasPermission(String permission) {
        if (permissions == null) {
            return false;
        }
        return permissions.contains(permission);
    }

    public String getId() {
        return id;
    }

    public static final class Property {
        @XmlAttribute
        private String name;
        @XmlValue
        private String value;

        private Property() {
        }

        Property(String name, String value) {
            this.name = name;
            this.value = value;
        }
    }
}
